@@ -1,8 +1,8 @@
 /*
- * core-completion.c - completion for WeeChat commands
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-FileCopyrightText: 2006 Emmanuel Bouthenot <kolter@openics.org>
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
- * Copyright (C) 2006 Emmanuel Bouthenot <kolter@openics.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -20,6 +20,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Completion for WeeChat commands */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -71,17 +73,12 @@ completion_list_add_quoted_word (struct t_gui_completion *completion,
                                  const char *word)
 {
     char *temp;
-    int length;
 
-    length = 1 + strlen (word) + 1 + 1;
-    temp = malloc (length);
-    if (!temp)
-        return;
-
-    snprintf (temp, length, "\"%s\"", word);
-    gui_completion_list_add (completion, temp, 0, WEECHAT_LIST_POS_END);
-
-    free (temp);
+    if (string_asprintf (&temp, "\"%s\"", word) >= 0)
+    {
+        gui_completion_list_add (completion, temp, 0, WEECHAT_LIST_POS_END);
+        free (temp);
+    }
 }
 
 /*
@@ -1015,6 +1012,33 @@ completion_list_add_filters_enabled_cb (const void *pointer, void *data,
     return WEECHAT_RC_OK;
 }
 
+/*
+ * Adds command hook types to completion list.
+ */
+
+int
+completion_list_add_hook_types_cb (const void *pointer, void *data,
+                                   const char *completion_item,
+                                   struct t_gui_buffer *buffer,
+                                   struct t_gui_completion *completion)
+{
+    int i;
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) completion_item;
+    (void) buffer;
+
+    for (i = 0; i < HOOK_NUM_TYPES; i++)
+    {
+        gui_completion_list_add (completion, hook_type_string[i],
+                                 0, WEECHAT_LIST_POS_SORT);
+    }
+
+    return WEECHAT_RC_OK;
+}
+
 /*
  * Adds command hooks to completion list.
  */
@@ -1194,7 +1218,6 @@ completion_list_add_config_options_cb (const void *pointer, void *data,
     struct t_config_file *ptr_config;
     struct t_config_section *ptr_section;
     struct t_config_option *ptr_option;
-    int length;
     char *option_full_name;
 
     /* make C compiler happy */
@@ -1212,15 +1235,12 @@ completion_list_add_config_options_cb (const void *pointer, void *data,
             for (ptr_option = ptr_section->options; ptr_option;
                  ptr_option = ptr_option->next_option)
             {
-                length = strlen (ptr_config->name) + 1
-                    + strlen (ptr_section->name) + 1
-                    + strlen (ptr_option->name) + 1;
-                option_full_name = malloc (length);
-                if (option_full_name)
+                if (string_asprintf (&option_full_name,
+                                     "%s.%s.%s",
+                                     ptr_config->name,
+                                     ptr_section->name,
+                                     ptr_option->name) >= 0)
                 {
-                    snprintf (option_full_name, length, "%s.%s.%s",
-                              ptr_config->name, ptr_section->name,
-                              ptr_option->name);
                     gui_completion_list_add (completion,
                                              option_full_name,
                                              0, WEECHAT_LIST_POS_SORT);
@@ -1307,7 +1327,6 @@ completion_list_add_plugins_installed_cb (const void *pointer, void *data,
                                           struct t_gui_completion *completion)
 {
     char *plugin_path, *dir_name, *extra_libdir;
-    int length;
     struct t_hashtable *options;
 
     /* make C compiler happy */
@@ -1320,11 +1339,8 @@ completion_list_add_plugins_installed_cb (const void *pointer, void *data,
     extra_libdir = getenv (WEECHAT_EXTRA_LIBDIR);
     if (extra_libdir && extra_libdir[0])
     {
-        length = strlen (extra_libdir) + 16 + 1;
-        dir_name = malloc (length);
-        if (dir_name)
+        if (string_asprintf (&dir_name, "%s/plugins", extra_libdir) >= 0)
         {
-            snprintf (dir_name, length, "%s/plugins", extra_libdir);
             dir_exec_on_files (dir_name, 1, 0,
                                &completion_list_add_plugins_installed_exec_cb,
                                completion);
@@ -1356,11 +1372,8 @@ completion_list_add_plugins_installed_cb (const void *pointer, void *data,
     }
 
     /* plugins in WeeChat global lib dir */
-    length = strlen (WEECHAT_LIBDIR) + 16 + 1;
-    dir_name = malloc (length);
-    if (dir_name)
+    if (string_asprintf (&dir_name, "%s/plugins", WEECHAT_LIBDIR) >= 0)
     {
-        snprintf (dir_name, length, "%s/plugins", WEECHAT_LIBDIR);
         dir_exec_on_files (dir_name, 1, 0,
                            &completion_list_add_plugins_installed_exec_cb,
                            completion);
@@ -1471,9 +1484,8 @@ completion_list_add_config_option_values_cb (const void *pointer, void *data,
                                              struct t_gui_completion *completion)
 {
     char *pos_space, *option_full_name, *pos_section, *pos_option;
-    char *file, *section, *value_string;
+    char *file, *section, *value_string, **ptr_value;
     const char *color_name;
-    int length, i;
     struct t_config_file *ptr_config;
     struct t_config_section *ptr_section, *section_found;
     struct t_config_option *option_found;
@@ -1560,12 +1572,11 @@ completion_list_add_config_option_values_cb (const void *pointer, void *data,
                                                          0, WEECHAT_LIST_POS_BEGINNING);
                             if (option_found->value)
                             {
-                                length = 64;
-                                value_string = malloc (length);
-                                if (value_string)
+                                if (string_asprintf (
+                                        &value_string,
+                                        "%d",
+                                        CONFIG_INTEGER(option_found)) >= 0)
                                 {
-                                    snprintf (value_string, length,
-                                              "%d", CONFIG_INTEGER(option_found));
                                     gui_completion_list_add (completion,
                                                              value_string,
                                                              0, WEECHAT_LIST_POS_BEGINNING);
@@ -1585,13 +1596,11 @@ completion_list_add_config_option_values_cb (const void *pointer, void *data,
                                                      0, WEECHAT_LIST_POS_BEGINNING);
                             if (option_found->value)
                             {
-                                length = strlen (CONFIG_STRING(option_found)) + 2 + 1;
-                                value_string = malloc (length);
-                                if (value_string)
+                                if (string_asprintf (
+                                        &value_string,
+                                        "\"%s\"",
+                                        CONFIG_STRING(option_found)) >= 0)
                                 {
-                                    snprintf (value_string, length,
-                                              "\"%s\"",
-                                              CONFIG_STRING(option_found));
                                     gui_completion_list_add (completion,
                                                              value_string,
                                                              0, WEECHAT_LIST_POS_BEGINNING);
@@ -1631,10 +1640,11 @@ completion_list_add_config_option_values_cb (const void *pointer, void *data,
                             }
                             break;
                         case CONFIG_OPTION_TYPE_ENUM:
-                            for (i = 0; option_found->string_values[i]; i++)
+                            for (ptr_value = option_found->string_values;
+                                 *ptr_value; ptr_value++)
                             {
                                 gui_completion_list_add (completion,
-                                                         option_found->string_values[i],
+                                                         *ptr_value,
                                                          0, WEECHAT_LIST_POS_SORT);
                             }
                             gui_completion_list_add (completion, "++1",
@@ -2015,8 +2025,7 @@ completion_list_add_env_vars_cb (const void *pointer, void *data,
                                  struct t_gui_buffer *buffer,
                                  struct t_gui_completion *completion)
 {
-    int i;
-    char *pos, *name;
+    char *pos, *name, **ptr_environ;
 
     /* make C compiler happy */
     (void) pointer;
@@ -2024,12 +2033,12 @@ completion_list_add_env_vars_cb (const void *pointer, void *data,
     (void) completion_item;
     (void) buffer;
 
-    for (i = 0; environ[i]; i++)
+    for (ptr_environ = environ; *ptr_environ; ptr_environ++)
     {
-        pos = strchr (environ[i], '=');
+        pos = strchr (*ptr_environ, '=');
         if (pos)
         {
-            name = string_strndup (environ[i], pos - environ[i]);
+            name = string_strndup (*ptr_environ, pos - *ptr_environ);
             if (name)
             {
                 gui_completion_list_add (completion, name,
@@ -2099,17 +2108,13 @@ completion_list_map_eval_buffer_local_variable_cb (void *data,
                                                    const void *key, const void *value)
 {
     char *name;
-    int length;
 
     /* make C compiler happy */
     (void) hashtable;
     (void) value;
 
-    length = strlen (key) + 3 + 1;
-    name = malloc (length);
-    if (name)
+    if (string_asprintf (&name, "${%s}", (const char *)key) >= 0)
     {
-        snprintf (name, length, "${%s}", (const char *)key);
         gui_completion_list_add ((struct t_gui_completion *)data,
                                  name, 0, WEECHAT_LIST_POS_SORT);
         free (name);
@@ -2224,7 +2229,7 @@ completion_list_add_eval_variables_cb (const void *pointer, void *data,
  */
 
 void
-completion_init ()
+completion_init (void)
 {
     hook_completion (NULL, "buffers_names", /* formerly "%b" */
                      N_("names of buffers"),
@@ -2276,6 +2281,9 @@ completion_init ()
     hook_completion (NULL, "filters_names_enabled",
                      N_("names of enabled filters"),
                      &completion_list_add_filters_enabled_cb, NULL, NULL);
+    hook_completion (NULL, "hook_types",
+                     N_("hook types"),
+                     &completion_list_add_hook_types_cb, NULL, NULL);
     hook_completion (NULL, "commands", /* formerly "%h" */
                      N_("commands (weechat and plugins); "
                         "optional argument: prefix to add before the commands"),
