@@ -1,5 +1,7 @@
 /*
- * Copyright (C) 2011-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-FileCopyrightText: 2011-2025 Sébastien Helleu <flashcode@flashtux.org>
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,11 +16,11 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef WEECHAT_GUI_CURSOR_H
-#define WEECHAT_GUI_CURSOR_H 1
+#define WEECHAT_GUI_CURSOR_H
 
 /* cursor variables */
 
@@ -29,11 +31,13 @@ extern int gui_cursor_y;
 
 /* cursor functions */
 
-extern void gui_cursor_mode_toggle ();
+extern void gui_cursor_mode_toggle (void);
+extern void gui_cursor_mode_stop (void);
 extern void gui_cursor_debug_set (int debug);
 extern void gui_cursor_move_xy (int x, int y);
 extern void gui_cursor_move_add_xy (int add_x, int add_y);
+extern void gui_cursor_move_position (const char *position);
 extern void gui_cursor_move_area_add_xy (int add_x, int add_y);
-extern void gui_cursor_move_area (const char *area);
+extern void gui_cursor_move_area (const char *area, const char *position);
 
 #endif /* WEECHAT_GUI_CURSOR_H */
