@@ -1,8 +1,8 @@
 /*
- * script-api.c - script API functions, used by script plugins
+ * SPDX-FileCopyrightText: 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-FileCopyrightText: 2012 Simon Arlott
  *
- * Copyright (C) 2003-2023 Sébastien Helleu <flashcode@flashtux.org>
- * Copyright (C) 2012 Simon Arlott
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -20,6 +20,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Script API functions, used by script plugins */
+
 #include <stdlib.h>
 #include <string.h>
 #include <stdarg.h>
@@ -41,9 +43,7 @@ plugin_script_api_charset_set (struct t_plugin_script *script,
     if (!script)
         return;
 
-    if (script->charset)
-        free (script->charset);
-
+    free (script->charset);
     script->charset = (charset) ? strdup (charset) : NULL;
 }
 
@@ -74,8 +74,7 @@ plugin_script_api_string_match_list (struct t_weechat_plugin *weechat_plugin,
                                        (const char **)list_masks,
                                        case_sensitive);
 
-    if (list_masks)
-        weechat_string_free_split (list_masks);
+    weechat_string_free_split (list_masks);
 
     return match;
 }
@@ -248,16 +247,11 @@ plugin_script_api_config_new_section (struct t_weechat_plugin *weechat_plugin,
 
     if (!new_section)
     {
-        if (function_and_data_read)
-            free (function_and_data_read);
-        if (function_and_data_write)
-            free (function_and_data_write);
-        if (function_and_data_write_default)
-            free (function_and_data_write_default);
-        if (function_and_data_create_option)
-            free (function_and_data_create_option);
-        if (function_and_data_delete_option)
-            free (function_and_data_delete_option);
+        free (function_and_data_read);
+        free (function_and_data_write);
+        free (function_and_data_write_default);
+        free (function_and_data_create_option);
+        free (function_and_data_delete_option);
     }
 
     return new_section;
@@ -328,12 +322,9 @@ plugin_script_api_config_new_option (struct t_weechat_plugin *weechat_plugin,
 
     if (!new_option)
     {
-        if (function_and_data_check_value)
-            free (function_and_data_check_value);
-        if (function_and_data_change)
-            free (function_and_data_change);
-        if (function_and_data_delete)
-            free (function_and_data_delete);
+        free (function_and_data_check_value);
+        free (function_and_data_change);
+        free (function_and_data_delete);
     }
 
     return new_option;
@@ -357,8 +348,7 @@ plugin_script_api_printf (struct t_weechat_plugin *weechat_plugin,
     buf2 = (script && script->charset && script->charset[0]) ?
         weechat_iconv_to_internal (script->charset, vbuffer) : NULL;
     weechat_printf (buffer, "%s", (buf2) ? buf2 : vbuffer);
-    if (buf2)
-        free (buf2);
+    free (buf2);
 
     free (vbuffer);
 }
@@ -384,8 +374,34 @@ plugin_script_api_printf_date_tags (struct t_weechat_plugin *weechat_plugin,
         weechat_iconv_to_internal (script->charset, vbuffer) : NULL;
     weechat_printf_date_tags (buffer, date, tags,
                               "%s", (buf2) ? buf2 : vbuffer);
-    if (buf2)
-        free (buf2);
+    free (buf2);
+
+    free (vbuffer);
+}
+
+/*
+ * Prints a message, with optional date/time (with microseconds) and tags.
+ */
+
+void
+plugin_script_api_printf_datetime_tags (struct t_weechat_plugin *weechat_plugin,
+                                        struct t_plugin_script *script,
+                                        struct t_gui_buffer *buffer,
+                                        time_t date, int date_usec,
+                                        const char *tags,
+                                        const char *format, ...)
+{
+    char *buf2;
+
+    weechat_va_format (format);
+    if (!vbuffer)
+        return;
+
+    buf2 = (script && script->charset && script->charset[0]) ?
+        weechat_iconv_to_internal (script->charset, vbuffer) : NULL;
+    weechat_printf_datetime_tags (buffer, date, date_usec, tags,
+                                  "%s", (buf2) ? buf2 : vbuffer);
+    free (buf2);
 
     free (vbuffer);
 }
@@ -409,8 +425,7 @@ plugin_script_api_printf_y (struct t_weechat_plugin *weechat_plugin,
     buf2 = (script && script->charset && script->charset[0]) ?
         weechat_iconv_to_internal (script->charset, vbuffer) : NULL;
     weechat_printf_y (buffer, y, "%s", (buf2) ? buf2 : vbuffer);
-    if (buf2)
-        free (buf2);
+    free (buf2);
 
     free (vbuffer);
 }
@@ -436,8 +451,35 @@ plugin_script_api_printf_y_date_tags (struct t_weechat_plugin *weechat_plugin,
         weechat_iconv_to_internal (script->charset, vbuffer) : NULL;
     weechat_printf_y_date_tags (buffer, y, date, tags,
                                 "%s", (buf2) ? buf2 : vbuffer);
-    if (buf2)
-        free (buf2);
+    free (buf2);
+
+    free (vbuffer);
+}
+
+/*
+ * Prints a message on a buffer with free content, with optional date/time
+ * (with microseconds) and tags.
+ */
+
+void
+plugin_script_api_printf_y_datetime_tags (struct t_weechat_plugin *weechat_plugin,
+                                          struct t_plugin_script *script,
+                                          struct t_gui_buffer *buffer, int y,
+                                          time_t date, int date_usec,
+                                          const char *tags,
+                                          const char *format, ...)
+{
+    char *buf2;
+
+    weechat_va_format (format);
+    if (!vbuffer)
+        return;
+
+    buf2 = (script && script->charset && script->charset[0]) ?
+        weechat_iconv_to_internal (script->charset, vbuffer) : NULL;
+    weechat_printf_y_datetime_tags (buffer, y, date, date_usec, tags,
+                                    "%s", (buf2) ? buf2 : vbuffer);
+    free (buf2);
 
     free (vbuffer);
 }
@@ -460,8 +502,7 @@ plugin_script_api_log_printf (struct t_weechat_plugin *weechat_plugin,
     buf2 = (script && script->charset && script->charset[0]) ?
         weechat_iconv_to_internal (script->charset, vbuffer) : NULL;
     weechat_log_printf ("%s", (buf2) ? buf2 : vbuffer);
-    if (buf2)
-        free (buf2);
+    free (buf2);
 
     free (vbuffer);
 }
@@ -499,14 +540,9 @@ plugin_script_api_hook_command (struct t_weechat_plugin *weechat_plugin,
                                      callback, script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -540,14 +576,9 @@ plugin_script_api_hook_command_run (struct t_weechat_plugin *weechat_plugin,
                                          callback, script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -580,14 +611,9 @@ plugin_script_api_hook_timer (struct t_weechat_plugin *weechat_plugin,
                                    callback, script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -621,14 +647,9 @@ plugin_script_api_hook_fd (struct t_weechat_plugin *weechat_plugin,
                                 callback, script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -667,14 +688,9 @@ plugin_script_api_hook_process_hashtable (struct t_weechat_plugin *weechat_plugi
                                                function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -704,6 +720,45 @@ plugin_script_api_hook_process (struct t_weechat_plugin *weechat_plugin,
                                                      callback, function, data);
 }
 
+/*
+ * Hooks a URL.
+ *
+ * Returns pointer to new hook, NULL if error.
+ */
+
+struct t_hook *
+plugin_script_api_hook_url (struct t_weechat_plugin *weechat_plugin,
+                            struct t_plugin_script *script,
+                            const char *url,
+                            struct t_hashtable *options,
+                            int timeout,
+                            int (*callback)(const void *pointer,
+                                            void *data,
+                                            const char *url,
+                                            struct t_hashtable *options,
+                                            struct t_hashtable *output),
+                            const char *function,
+                            const char *data)
+{
+    char *function_and_data;
+    struct t_hook *new_hook;
+
+    if (!script)
+        return NULL;
+
+    function_and_data = plugin_script_build_function_and_data (function, data);
+
+    new_hook = weechat_hook_url (url, options, timeout,
+                                 callback, script, function_and_data);
+
+    if (new_hook)
+        weechat_hook_set (new_hook, "subplugin", script->name);
+    else
+        free (function_and_data);
+
+    return new_hook;
+}
+
 /*
  * Hooks a connection to a peer (using fork).
  *
@@ -743,14 +798,9 @@ plugin_script_api_hook_connect (struct t_weechat_plugin *weechat_plugin,
                                      callback, script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -785,14 +835,9 @@ plugin_script_api_hook_line (struct t_weechat_plugin *weechat_plugin,
                                   script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -813,6 +858,7 @@ plugin_script_api_hook_print (struct t_weechat_plugin *weechat_plugin,
                                               void *data,
                                               struct t_gui_buffer *buffer,
                                               time_t date,
+                                              int date_usec,
                                               int tags_count,
                                               const char **tags,
                                               int displayed, int highlight,
@@ -833,14 +879,9 @@ plugin_script_api_hook_print (struct t_weechat_plugin *weechat_plugin,
                                    callback, script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -875,14 +916,9 @@ plugin_script_api_hook_signal (struct t_weechat_plugin *weechat_plugin,
                                     function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -916,14 +952,9 @@ plugin_script_api_hook_hsignal (struct t_weechat_plugin *weechat_plugin,
                                      function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -957,14 +988,9 @@ plugin_script_api_hook_config (struct t_weechat_plugin *weechat_plugin,
                                     function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -1000,14 +1026,9 @@ plugin_script_api_hook_completion (struct t_weechat_plugin *weechat_plugin,
                                         callback, script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -1042,14 +1063,9 @@ plugin_script_api_hook_modifier (struct t_weechat_plugin *weechat_plugin,
                                       callback, script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -1085,14 +1101,9 @@ plugin_script_api_hook_info (struct t_weechat_plugin *weechat_plugin,
                                   callback, script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -1132,14 +1143,9 @@ plugin_script_api_hook_info_hashtable (struct t_weechat_plugin *weechat_plugin,
                                             function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -1178,14 +1184,9 @@ plugin_script_api_hook_infolist (struct t_weechat_plugin *weechat_plugin,
                                       callback, script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -1217,14 +1218,9 @@ plugin_script_api_hook_focus (struct t_weechat_plugin *weechat_plugin,
     new_hook = weechat_hook_focus (area, callback, script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -1287,10 +1283,8 @@ plugin_script_api_buffer_new_props (struct t_weechat_plugin *weechat_plugin,
     }
     else
     {
-        if (function_and_data_input)
-            free (function_and_data_input);
-        if (function_and_data_close)
-            free (function_and_data_close);
+        free (function_and_data_input);
+        free (function_and_data_close);
     }
 
     return new_buffer;
@@ -1403,8 +1397,7 @@ plugin_script_api_command_options (struct t_weechat_plugin *weechat_plugin,
                                   (command2) ? command2 : command,
                                   options);
 
-    if (command2)
-        free (command2);
+    free (command2);
 
     return rc;
 }
@@ -1422,6 +1415,23 @@ plugin_script_api_command (struct t_weechat_plugin *weechat_plugin,
                                               command, NULL);
 }
 
+/*
+ * Builds full name of option: "script.option".
+ *
+ * Note: result must be freed after use.
+ */
+
+char *
+plugin_script_api_build_option_full_name (struct t_weechat_plugin *weechat_plugin,
+                                          struct t_plugin_script *script,
+                                          const char *option)
+{
+    char *option_full_name;
+
+    weechat_asprintf (&option_full_name, "%s.%s", script->name, option);
+    return option_full_name;
+}
+
 /*
  * Gets value of a script option (format in file is "plugin.script.option").
  */
@@ -1431,24 +1441,20 @@ plugin_script_api_config_get_plugin (struct t_weechat_plugin *weechat_plugin,
                                      struct t_plugin_script *script,
                                      const char *option)
 {
-    char *option_fullname;
+    char *option_full_name;
     const char *return_value;
 
     if (!script)
         return NULL;
 
-    option_fullname = malloc ((strlen (script->name) +
-                               strlen (option) + 2));
-    if (!option_fullname)
+    option_full_name = plugin_script_api_build_option_full_name (
+        weechat_plugin, script, option);
+    if (!option_full_name)
         return NULL;
 
-    strcpy (option_fullname, script->name);
-    strcat (option_fullname, ".");
-    strcat (option_fullname, option);
+    return_value = weechat_config_get_plugin (option_full_name);
 
-    return_value = weechat_config_get_plugin (option_fullname);
-
-    free (option_fullname);
+    free (option_full_name);
 
     return return_value;
 }
@@ -1466,24 +1472,20 @@ plugin_script_api_config_is_set_plugin (struct t_weechat_plugin *weechat_plugin,
                                         struct t_plugin_script *script,
                                         const char *option)
 {
-    char *option_fullname;
+    char *option_full_name;
     int return_code;
 
     if (!script)
         return 0;
 
-    option_fullname = malloc ((strlen (script->name) +
-                               strlen (option) + 2));
-    if (!option_fullname)
+    option_full_name = plugin_script_api_build_option_full_name (
+        weechat_plugin, script, option);
+    if (!option_full_name)
         return 0;
 
-    strcpy (option_fullname, script->name);
-    strcat (option_fullname, ".");
-    strcat (option_fullname, option);
+    return_code = weechat_config_is_set_plugin (option_full_name);
 
-    return_code = weechat_config_is_set_plugin (option_fullname);
-
-    free (option_fullname);
+    free (option_full_name);
 
     return return_code;
 }
@@ -1497,24 +1499,20 @@ plugin_script_api_config_set_plugin (struct t_weechat_plugin *weechat_plugin,
                                      struct t_plugin_script *script,
                                      const char *option, const char *value)
 {
-    char *option_fullname;
+    char *option_full_name;
     int return_code;
 
     if (!script)
         return 0;
 
-    option_fullname = malloc ((strlen (script->name) +
-                               strlen (option) + 2));
-    if (!option_fullname)
+    option_full_name = plugin_script_api_build_option_full_name (
+        weechat_plugin, script, option);
+    if (!option_full_name)
         return 0;
 
-    strcpy (option_fullname, script->name);
-    strcat (option_fullname, ".");
-    strcat (option_fullname, option);
+    return_code = weechat_config_set_plugin (option_full_name, value);
 
-    return_code = weechat_config_set_plugin (option_fullname, value);
-
-    free (option_fullname);
+    free (option_full_name);
 
     return return_code;
 }
@@ -1528,23 +1526,19 @@ plugin_script_api_config_set_desc_plugin (struct t_weechat_plugin *weechat_plugi
                                           struct t_plugin_script *script,
                                           const char *option, const char *description)
 {
-    char *option_fullname;
+    char *option_full_name;
 
     if (!script)
         return;
 
-    option_fullname = malloc ((strlen (script->name) +
-                               strlen (option) + 2));
-    if (!option_fullname)
+    option_full_name = plugin_script_api_build_option_full_name (
+        weechat_plugin, script, option);
+    if (!option_full_name)
         return;
 
-    strcpy (option_fullname, script->name);
-    strcat (option_fullname, ".");
-    strcat (option_fullname, option);
+    weechat_config_set_desc_plugin (option_full_name, description);
 
-    weechat_config_set_desc_plugin (option_fullname, description);
-
-    free (option_fullname);
+    free (option_full_name);
 }
 
 /*
@@ -1556,24 +1550,20 @@ plugin_script_api_config_unset_plugin (struct t_weechat_plugin *weechat_plugin,
                                        struct t_plugin_script *script,
                                        const char *option)
 {
-    char *option_fullname;
+    char *option_full_name;
     int return_code;
 
     if (!script)
         return 0;
 
-    option_fullname = malloc ((strlen (script->name) +
-                               strlen (option) + 2));
-    if (!option_fullname)
+    option_full_name = plugin_script_api_build_option_full_name (
+        weechat_plugin, script, option);
+    if (!option_full_name)
         return 0;
 
-    strcpy (option_fullname, script->name);
-    strcat (option_fullname, ".");
-    strcat (option_fullname, option);
+    return_code = weechat_config_unset_plugin (option_full_name);
 
-    return_code = weechat_config_unset_plugin (option_fullname);
-
-    free (option_fullname);
+    free (option_full_name);
 
     return return_code;
 }
