@@ -1,7 +1,7 @@
 /*
- * trigger-command.c - trigger command
+ * SPDX-FileCopyrightText: 2014-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2014-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Trigger command */
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <stdarg.h>
@@ -35,7 +37,7 @@
  */
 
 void
-trigger_command_display_status ()
+trigger_command_display_status (void)
 {
     weechat_printf_date_tags (NULL, 0, "no_trigger",
                               (trigger_enabled) ?
@@ -64,7 +66,7 @@ trigger_command_display_trigger_internal (const char *name,
                                           int verbose)
 {
     char str_conditions[64], str_regex[64], str_command[64], str_rc[64];
-    char str_post_action[64], spaces[256];
+    char str_post_action[64], spaces[256], **ptr_command;
     int i, length;
 
     if (verbose >= 1)
@@ -133,7 +135,7 @@ trigger_command_display_trigger_internal (const char *name,
         }
         if (commands)
         {
-            for (i = 0; commands[i]; i++)
+            for (ptr_command = commands, i = 0; *ptr_command; ptr_command++, i++)
             {
                 weechat_printf_date_tags (
                     NULL, 0, "no_trigger",
@@ -143,7 +145,7 @@ trigger_command_display_trigger_internal (const char *name,
                     i + 1,
                     weechat_color ("chat_delimiters"),
                     weechat_color ("reset"),
-                    commands[i],
+                    *ptr_command,
                     weechat_color ("chat_delimiters"));
             }
         }
@@ -436,8 +438,7 @@ trigger_command_list_default (int verbose)
     }
 
     trigger_regex_free (&regex_count, &regex);
-    if (commands)
-        weechat_string_free_split (commands);
+    weechat_string_free_split (commands);
 }
 
 /*
@@ -448,7 +449,7 @@ void
 trigger_command_error_running (struct t_trigger *trigger, const char *action)
 {
     weechat_printf_date_tags (NULL, 0, "no_trigger",
-                              _("%s%s: action \"%s\" can not be executed on "
+                              _("%s%s: action \"%s\" cannot be executed on "
                                 "trigger \"%s\" because it is currently "
                                 "running"),
                               weechat_prefix ("error"), TRIGGER_PLUGIN_NAME,
@@ -488,7 +489,7 @@ trigger_command_set_enabled (struct t_trigger *trigger,
         else if (display_error)
         {
             weechat_printf_date_tags (NULL, 0, "no_trigger",
-                                      _("%s%s: a disabled trigger can not be "
+                                      _("%s%s: a disabled trigger cannot be "
                                         "restarted"),
                                       weechat_prefix ("error"),
                                       TRIGGER_PLUGIN_NAME);
@@ -568,10 +569,8 @@ trigger_command_rename (struct t_trigger *trigger, const char *new_name)
     }
 
 end:
-    if (name)
-        free (name);
-    if (name2)
-        free (name2);
+    free (name);
+    free (name2);
 }
 
 /*
@@ -840,8 +839,7 @@ trigger_command_trigger (const void *pointer, void *data,
             weechat_buffer_set (buffer, "input_pos", "13");
             free (input);
         }
-        if (items)
-            weechat_string_free_split (items);
+        weechat_string_free_split (items);
         goto end;
     }
 
@@ -892,18 +890,12 @@ trigger_command_trigger (const void *pointer, void *data,
             arg_command,
             arg_return_code,
             arg_post_action);
-        if (arg_arguments)
-            free (arg_arguments);
-        if (arg_conditions)
-            free (arg_conditions);
-        if (arg_regex)
-            free (arg_regex);
-        if (arg_command)
-            free (arg_command);
-        if (arg_return_code)
-            free (arg_return_code);
-        if (arg_post_action)
-            free (arg_post_action);
+        free (arg_arguments);
+        free (arg_conditions);
+        free (arg_regex);
+        free (arg_command);
+        free (arg_return_code);
+        free (arg_post_action);
         if (input)
         {
             if (weechat_strcmp (argv[1], "output") == 0)
@@ -1121,8 +1113,7 @@ trigger_command_trigger (const void *pointer, void *data,
                         weechat_printf_date_tags (NULL, 0, "no_trigger",
                                                   _("Trigger \"%s\" removed"),
                                                   name);
-                        if (name)
-                            free (name);
+                        free (name);
                     }
                 }
                 ptr_trigger = ptr_next_trigger;
@@ -1172,8 +1163,7 @@ trigger_command_trigger (const void *pointer, void *data,
                     }
                     else
                     {
-                        if (ptr_trigger)
-                            trigger_free (ptr_trigger);
+                        trigger_free (ptr_trigger);
                         ptr_trigger = trigger_new (
                             trigger_config_default_list[j][0],   /* name */
                             trigger_config_default_list[j][1],   /* enabled */
@@ -1251,8 +1241,7 @@ error:
     rc = WEECHAT_RC_ERROR;
 
 end:
-    if (sargv)
-        weechat_string_free_split (sargv);
+    weechat_string_free_split (sargv);
 
     if (rc == WEECHAT_RC_ERROR)
         WEECHAT_COMMAND_ERROR;
@@ -1265,12 +1254,12 @@ end:
  */
 
 void
-trigger_command_init ()
+trigger_command_init (void)
 {
     weechat_hook_command (
         "trigger",
         N_("manage triggers, the Swiss Army knife for WeeChat"),
-        /* TRANSLATORS: only text between angle brackets (eg: "<name>") must be translated */
+        /* TRANSLATORS: only text between angle brackets (eg: "<name>") may be translated */
         N_("list [-o|-ol|-i|-il]"
            " || listfull"
            " || listdefault"
@@ -1281,11 +1270,11 @@ trigger_command_init ()
            " || input|output|recreate <name>"
            " || set <name> <option> <value>"
            " || rename|copy <name> <new_name>"
-           " || enable|disable|toggle [<name>|<mask> [<name>|<mask>...]]"
-           " || restart <name>|<mask> [<name>|<mask>...]"
+           " || enable|disable|toggle [<name>|<mask>...]"
+           " || restart <name>|<mask>..."
            " || show <name>"
-           " || del <name>|<mask> [<name>|<mask>...]"
-           " || restore <name>|<mask> [<name>|<mask>...]"
+           " || del <name>|<mask>..."
+           " || restore <name>|<mask>..."
            " || default -yes"
            " || monitor [<filter>]"),
         WEECHAT_CMD_ARGS_DESC(
