@@ -1,7 +1,7 @@
 /*
- * test-core-crypto.cpp - test cryptographic functions
+ * SPDX-FileCopyrightText: 2020-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2020-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,8 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Test cryptographic functions */
+
 #include "CppUTest/TestHarness.h"
 
 extern "C"
@@ -28,8 +30,8 @@ extern "C"
 #include <string.h>
 #include <ctype.h>
 #include <gcrypt.h>
-#include "src/core/wee-crypto.h"
-#include "src/core/wee-string.h"
+#include "src/core/core-crypto.h"
+#include "src/core/core-string.h"
 
 /* Hash */
 #define DATA_HASH_MSG "this is a test of hash function"
@@ -208,16 +210,8 @@ extern "C"
 
 #define WEE_CHECK_TOTP_GENERATE(__result, __secret, __time, __digits)   \
     totp = weecrypto_totp_generate (__secret, __time, __digits);        \
-    if (__result == NULL)                                               \
-    {                                                                   \
-        POINTERS_EQUAL(NULL, totp);                                     \
-    }                                                                   \
-    else                                                                \
-    {                                                                   \
-        STRCMP_EQUAL(__result, totp);                                   \
-    }                                                                   \
-    if (totp)                                                           \
-        free (totp);
+    STRCMP_EQUAL(__result, totp);                                       \
+    free (totp);
 
 #define WEE_CHECK_TOTP_VALIDATE(__result, __secret, __time, __window,   \
                                 __otp)                                  \
