@@ -1,7 +1,7 @@
 /*
- * test-logger-backlog.cpp - test logger backlog functions
+ * SPDX-FileCopyrightText: 2022-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2022-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,16 +19,18 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+/* Test logger backlog functions */
+
 #include "CppUTest/TestHarness.h"
 
-#include "tests/tests.h"
+#include "tests.h"
 
 extern "C"
 {
 #include <stdio.h>
 #include <string.h>
-#include "src/core/wee-arraylist.h"
-#include "src/core/wee-config.h"
+#include "src/core/core-arraylist.h"
+#include "src/core/core-config.h"
 #include "src/gui/gui-buffer.h"
 #include "src/gui/gui-color.h"
 #include "src/gui/gui-line.h"
