@@ -1,7 +1,7 @@
 /*
- * test-plugin-api-info.cpp - tests API info functions
+ * SPDX-FileCopyrightText: 2023-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
- * Copyright (C) 2023-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,9 +19,11 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+/* Tests API info functions */
+
 #include "CppUTest/TestHarness.h"
 
-#include "tests/tests.h"
+#include "tests.h"
 
 extern "C"
 {
@@ -31,16 +33,16 @@ extern "C"
 #include <unistd.h>
 #include <string.h>
 #include "src/core/weechat.h"
-#include "src/core/wee-config.h"
-#include "src/core/wee-config-file.h"
-#include "src/core/wee-hashtable.h"
-#include "src/core/wee-hook.h"
-#include "src/core/wee-infolist.h"
-#include "src/core/wee-input.h"
-#include "src/core/wee-proxy.h"
-#include "src/core/wee-secure.h"
-#include "src/core/wee-util.h"
-#include "src/core/wee-version.h"
+#include "src/core/core-config.h"
+#include "src/core/core-config-file.h"
+#include "src/core/core-hashtable.h"
+#include "src/core/core-hook.h"
+#include "src/core/core-infolist.h"
+#include "src/core/core-input.h"
+#include "src/core/core-proxy.h"
+#include "src/core/core-secure.h"
+#include "src/core/core-util.h"
+#include "src/core/core-version.h"
 #include "src/gui/gui-bar.h"
 #include "src/gui/gui-bar-item.h"
 #include "src/gui/gui-buffer.h"
@@ -81,7 +83,7 @@ TEST(PluginApiInfo, VersionNumberCb)
     char *str, str_version_number[128];
 
     snprintf (str_version_number, sizeof (str_version_number),
-              "%d", util_version_number (version_get_version ()));
+              "%lu", util_version_number (version_get_version ()));
     WEE_TEST_STR(str_version_number, hook_info_get (NULL, "version_number", NULL));
     WEE_TEST_STR(str_version_number, hook_info_get (NULL, "version_number", ""));
 
@@ -152,9 +154,9 @@ TEST(PluginApiInfo, AbsolutePath)
 {
     char *str;
 
-    POINTERS_EQUAL(NULL, plugin_api_info_absolute_path (NULL));
-    POINTERS_EQUAL(NULL, plugin_api_info_absolute_path (""));
-    POINTERS_EQUAL(NULL, plugin_api_info_absolute_path ("/invalid/dir"));
+    STRCMP_EQUAL(NULL, plugin_api_info_absolute_path (NULL));
+    STRCMP_EQUAL(NULL, plugin_api_info_absolute_path (""));
+    STRCMP_EQUAL(NULL, plugin_api_info_absolute_path ("/invalid/dir"));
 
     WEE_TEST_STR("/", plugin_api_info_absolute_path ("/tmp/.."));
 }
@@ -164,8 +166,9 @@ TEST(PluginApiInfo, AbsolutePath)
  *   plugin_api_info_absolute_path
  *   plugin_api_info_weechat_config_dir_cb
  *   plugin_api_info_weechat_data_dir_cb
+ *   plugin_api_info_weechat_state_dir_cb
  *   plugin_api_info_weechat_cache_dir_cb
- *   plugin_api_info_weechat_cache_dir_cb
+ *   plugin_api_info_weechat_runtime_dir_cb
  */
 
 TEST(PluginApiInfo, WeechatDir)
@@ -186,6 +189,13 @@ TEST(PluginApiInfo, WeechatDir)
     CHECK(strstr (str, "/tmp_weechat_test"));
     free (str);
 
+    str = hook_info_get (NULL, "weechat_state_dir", NULL);
+    CHECK(str);
+    CHECK(str[0] == '/');
+    CHECK(strlen (str) > 1);
+    CHECK(strstr (str, "/tmp_weechat_test"));
+    free (str);
+
     str = hook_info_get (NULL, "weechat_cache_dir", NULL);
     CHECK(str);
     CHECK(str[0] == '/');
@@ -332,12 +342,12 @@ TEST(PluginApiInfo, BufferCb)
 {
     char *str, str_buffer[64];
 
-    POINTERS_EQUAL(NULL, hook_info_get (NULL, "buffer", NULL));
-    POINTERS_EQUAL(NULL, hook_info_get (NULL, "buffer", ""));
+    STRCMP_EQUAL(NULL, hook_info_get (NULL, "buffer", NULL));
+    STRCMP_EQUAL(NULL, hook_info_get (NULL, "buffer", ""));
 
-    POINTERS_EQUAL(NULL, hook_info_get (NULL, "buffer", "zzz"));
+    STRCMP_EQUAL(NULL, hook_info_get (NULL, "buffer", "zzz"));
 
-    snprintf (str_buffer, sizeof (str_buffer), "0x%lx", (unsigned long)gui_buffers);
+    snprintf (str_buffer, sizeof (str_buffer), "%p", gui_buffers);
     WEE_TEST_STR(str_buffer, hook_info_get (NULL, "buffer", "core.weechat"));
 }
 
@@ -521,8 +531,8 @@ TEST(PluginApiInfo, ColorTerm2rgbCb)
 {
     char *str;
 
-    POINTERS_EQUAL(NULL, hook_info_get (NULL, "color_term2rgb", NULL));
-    POINTERS_EQUAL(NULL, hook_info_get (NULL, "color_term2rgb", ""));
+    STRCMP_EQUAL(NULL, hook_info_get (NULL, "color_term2rgb", NULL));
+    STRCMP_EQUAL(NULL, hook_info_get (NULL, "color_term2rgb", ""));
 
     WEE_TEST_STR("8421504", hook_info_get (NULL, "color_term2rgb", "8"));
     WEE_TEST_STR("11534080", hook_info_get (NULL, "color_term2rgb", "154"));
@@ -537,8 +547,8 @@ TEST(PluginApiInfo, ColorRgb2termCb)
 {
     char *str;
 
-    POINTERS_EQUAL(NULL, hook_info_get (NULL, "color_rgb2term", NULL));
-    POINTERS_EQUAL(NULL, hook_info_get (NULL, "color_rgb2term", ""));
+    STRCMP_EQUAL(NULL, hook_info_get (NULL, "color_rgb2term", NULL));
+    STRCMP_EQUAL(NULL, hook_info_get (NULL, "color_rgb2term", ""));
 
     WEE_TEST_STR("8", hook_info_get (NULL, "color_rgb2term", "8421504"));
     WEE_TEST_STR("154", hook_info_get (NULL, "color_rgb2term", "11534080"));
@@ -600,7 +610,7 @@ TEST(PluginApiInfo, Uptime)
     char *str, *error;
     long long seconds;
 
-    POINTERS_EQUAL(NULL, hook_info_get (NULL, "uptime", "invalid"));
+    STRCMP_EQUAL(NULL, hook_info_get (NULL, "uptime", "invalid"));
 
     str = hook_info_get (NULL, "uptime", NULL);
     STRNCMP_EQUAL("0:00:00:", str, 8);
@@ -632,21 +642,21 @@ TEST(PluginApiInfo, TotpGenerateCb)
 {
     char *str;
 
-    POINTERS_EQUAL(NULL, hook_info_get (NULL, "totp_generate", NULL));
-    POINTERS_EQUAL(NULL, hook_info_get (NULL, "totp_generate", ""));
+    STRCMP_EQUAL(NULL, hook_info_get (NULL, "totp_generate", NULL));
+    STRCMP_EQUAL(NULL, hook_info_get (NULL, "totp_generate", ""));
 
-    POINTERS_EQUAL(NULL, hook_info_get (NULL, "totp_validate", NULL));
-    POINTERS_EQUAL(NULL, hook_info_get (NULL, "totp_validate", ""));
+    STRCMP_EQUAL(NULL, hook_info_get (NULL, "totp_validate", NULL));
+    STRCMP_EQUAL(NULL, hook_info_get (NULL, "totp_validate", ""));
 
-    POINTERS_EQUAL(NULL, hook_info_get (NULL, "totp_generate",
-                                        "secretpasswordbase32,abc"));
-    POINTERS_EQUAL(NULL, hook_info_get (NULL, "totp_generate",
-                                        "secretpasswordbase32,1540624066,abc"));
+    STRCMP_EQUAL(NULL, hook_info_get (NULL, "totp_generate",
+                                      "secretpasswordbase32,abc"));
+    STRCMP_EQUAL(NULL, hook_info_get (NULL, "totp_generate",
+                                      "secretpasswordbase32,1540624066,abc"));
 
-    POINTERS_EQUAL(NULL, hook_info_get (NULL, "totp_validate",
-                                        "secretpasswordbase32,123456,abc"));
-    POINTERS_EQUAL(NULL, hook_info_get (NULL, "totp_validate",
-                                        "secretpasswordbase32,123456,1540624066,abc"));
+    STRCMP_EQUAL(NULL, hook_info_get (NULL, "totp_validate",
+                                      "secretpasswordbase32,123456,abc"));
+    STRCMP_EQUAL(NULL, hook_info_get (NULL, "totp_validate",
+                                      "secretpasswordbase32,123456,1540624066,abc"));
 
     WEE_TEST_STR("065486",
                  hook_info_get (NULL,
@@ -663,6 +673,24 @@ TEST(PluginApiInfo, TotpGenerateCb)
                                 "secretpasswordbase32,123456,1540624066,30"));
 }
 
+/*
+ * Tests functions:
+ *   plugin_api_info_plugin_loaded_cb
+ */
+
+TEST(PluginApiInfo, PluginLoadedCb)
+{
+    char *str;
+
+    STRCMP_EQUAL(NULL, hook_info_get (NULL, "plugin_loaded", NULL));
+    STRCMP_EQUAL(NULL, hook_info_get (NULL, "plugin_loaded", ""));
+
+    STRCMP_EQUAL(NULL, hook_info_get (NULL, "plugin_loaded", "xxx"));
+
+    WEE_TEST_STR("1", hook_info_get (NULL, "plugin_loaded", "alias"));
+    WEE_TEST_STR("1", hook_info_get (NULL, "plugin_loaded", "irc"));
+}
+
 /*
  * Tests functions:
  *   plugin_api_info_hashtable_secured_data_cb
@@ -943,7 +971,7 @@ TEST(PluginApiInfo, InfolistHistoryCb)
     infolist_free (infolist);
 
     /* history of core buffer */
-    input_data (gui_buffers, "abc", NULL, 1);
+    input_data (gui_buffers, "abc", NULL, 1, 0);
     infolist = hook_infolist_get (NULL, "history", gui_buffers, NULL);
     CHECK(infolist);
     CHECK(infolist_next (infolist));
@@ -1170,7 +1198,7 @@ TEST(PluginApiInfo, InfolistPluginCb)
     char *name;
 
     /* invalid plugin pointer */
-    infolist = hook_infolist_get (NULL, "plugin", (void *)0x1, NULL);
+    POINTERS_EQUAL(NULL, hook_infolist_get (NULL, "plugin", (void *)0x1, NULL));
 
     /* all plugins */
     infolist = hook_infolist_get (NULL, "plugin", NULL, NULL);
@@ -1214,7 +1242,7 @@ TEST(PluginApiInfo, InfolistProxyCb)
     struct t_proxy *ptr_proxy1, *ptr_proxy2;
 
     /* invalid proxy pointer */
-    infolist = hook_infolist_get (NULL, "proxy", (void *)0x1, NULL);
+    POINTERS_EQUAL(NULL, hook_infolist_get (NULL, "proxy", (void *)0x1, NULL));
 
     ptr_proxy1 = proxy_new ("proxy1", "http", "off",
                             "proxy1.example.com", "8000", "user1", "pass1");
